@@ -1,7 +1,6 @@
 QuestionFormToDataFrame <-
-function (xml = NULL, xml.parsed = NULL) 
-{
-    if (!is.null(xml)) 
+function (xml = NULL, xml.parsed = NULL) {
+    if(!is.null(xml)) 
         xml.parsed <- xmlParse(xml)
     qform <- xmlChildren(xmlChildren(xml.parsed)$QuestionForm)
     #overview <- qform[names(qform) == "Overview"]
@@ -10,7 +9,7 @@ function (xml = NULL, xml.parsed = NULL)
     qdf <- data.frame(matrix(nrow = length(questions), ncol = 5))
     names(qdf) <- c("QuestionIdentifier", "DisplayName", "IsRequired", 
         "QuestionContent", "AnswerSpecification")
-    for (i in 1:length(questions)) {
+    for(i in 1:length(questions)) {
         qdf$QuestionIdentifier[i] <- xmlValue(xmlChildren(questions[[i]])$QuestionIdentifier)
         qdf$DisplayName[i] <- xmlValue(xmlChildren(questions[[i]])$DisplayName)
         qdf$IsRequired[i] <- xmlValue(xmlChildren(questions[[i]])$IsRequired)
