@@ -1,8 +1,9 @@
 SufficientFunds <-
 function (amount, assignments = NULL, hits = NULL, bonus.ct = NULL, 
     bonus.amount = NULL, masters = FALSE, turkfee = 0.1, turkmin = 0.005, 
-    mastersfee = 0.2, keypair = credentials(), print = TRUE, 
-    log.requests = TRUE, sandbox = FALSE) 
+    mastersfee = 0.2, keypair = credentials(), print = getOption('MTurkR.print'), 
+    log.requests = getOption('MTurkR.log'), sandbox = getOption('MTurkR.sandbox'),
+    validation.test = getOption('MTurkR.test'))
 {
     total <- 0
     payments <- 0
@@ -42,32 +43,28 @@ function (amount, assignments = NULL, hits = NULL, bonus.ct = NULL,
         else bonus.fee <- turkfee * bonuses
         total <- total + bonuses + bonus.fee
     }
-    balchar <- AccountBalance(print = FALSE)
+    balchar <- AccountBalance(print = FALSE, validation.test = validation.test)
+	if(validation.test)
+		invisible(balchar)
     oldbalance <- as.numeric(substring(balchar, 1, nchar(balchar)))
     newbalance <- oldbalance - total
     if (newbalance >= 0) 
         sufficient <- TRUE
     else sufficient <- FALSE
     if (print == TRUE) {
-        cat("Total Payments:  $", round(payments, 2), "\n", sep = "")
-        cat("Payment Fee:     $", round(payment.fee, 2), "\n", 
-            sep = "")
-        cat("Masters Fee:     $", round(masters.fee, 2), "\n", 
-            sep = "")
-        cat("Bonuses:         $", round(bonuses, 2), "\n", sep = "")
-        cat("Bonus Fee:       $", round(bonus.fee, 2), "\n", 
-            sep = "")
-        cat("-------------------------\n")
-        cat("  Old Balance:   $", round(oldbalance, 2), "\n", 
-            sep = "")
-        cat("  Total Cost:    $", round(total, 2), "\n", sep = "")
+        message("Total Payments:  $", round(payments, 2))
+        message("Payment Fee:     $", round(payment.fee, 2))
+        message("Masters Fee:     $", round(masters.fee, 2))
+        message("Bonuses:         $", round(bonuses, 2))
+        message("Bonus Fee:       $", round(bonus.fee, 2))
+        message("-------------------------")
+        message("  Old Balance:   $", round(oldbalance, 2))
+        message("  Total Cost:    $", round(total, 2))
         if (sufficient == TRUE) 
-            cat("  New Balance:   $", round(newbalance, 2), " < SUFFICIENT\n", 
-                sep = "")
-        else cat("  New Balance:   $", round(newbalance, 2), 
-            " < INSUFFICIENT\n", sep = "")
-        cat("\n")
+            message("  New Balance:   $", round(newbalance, 2), " < SUFFICIENT\n")
+        else
+			message("  New Balance:   $", round(newbalance, 2), " < INSUFFICIENT\n")
     }
-    invisible(list(Total = round(total, 3), OldBalance = round(oldbalance, 
-        3), NewBalance = round(newbalance, 3), SufficientFunds = sufficient))
+    invisible(list(Total = round(total, 3), OldBalance = round(oldbalance, 3),
+					NewBalance = round(newbalance, 3), SufficientFunds = sufficient))
 }
